pub enum GmailYield {
WantsRead,
WantsWrite(Vec<u8>),
}Expand description
The I/O request a coroutine yields: read bytes from the stream, or write the given bytes to it.
Variants
WantsRead
The coroutine wants bytes read from the stream.
WantsWrite(Vec<u8>)
The coroutine wants the given bytes written to the stream.