pub enum GmailLabelListVisibility {
LabelShow,
LabelShowIfUnread,
LabelHide,
}Expand description
Visibility of the label in the label list of the Gmail web client.
Variants
LabelShow
The label always shows in the label list.
LabelShowIfUnread
The label shows in the label list only when unread.
LabelHide
The label never shows in the label list.