GmailLabel

Struct GmailLabel 

pub struct GmailLabel {
    pub id: String,
    pub name: String,
    pub label_type: Option<GmailLabelType>,
    pub message_list_visibility: Option<GmailMessageListVisibility>,
    pub label_list_visibility: Option<GmailLabelListVisibility>,
    pub messages_total: Option<u64>,
    pub messages_unread: Option<u64>,
    pub threads_total: Option<u64>,
    pub threads_unread: Option<u64>,
    pub color: Option<GmailLabelColor>,
}
A Gmail label resource.

Labels are used to categorize messages and threads within the user’s mailbox.

Fields

id: String

The immutable id of the label.

name: String

The display name of the label.

label_type: Option<GmailLabelType>

The owner type of the label, serialized as type.

message_list_visibility: Option<GmailMessageListVisibility>

The visibility of messages with this label in the message list.

label_list_visibility: Option<GmailLabelListVisibility>

The visibility of the label in the label list.

messages_total: Option<u64>

The total number of messages with the label.

messages_unread: Option<u64>

The number of unread messages with the label.

threads_total: Option<u64>

The total number of threads with the label.

threads_unread: Option<u64>

The number of unread threads with the label.

color: Option<GmailLabelColor>

The color of the label; only available for user labels.