pub struct GmailLabelColor {
pub text_color: Option<String>,
pub background_color: Option<String>,
}Expand description
Text and background colors of a user label, given as hex strings.
Fields
text_color: Option<String>The text color of the label as a hex string.
background_color: Option<String>The background color of the label as a hex string.