GmailMessagesBatchModify

Struct GmailMessagesBatchModify 

pub struct GmailMessagesBatchModify { /* private fields */ }
Gmail REST batch message label modification, yielding no response body.

Implementations

Source

impl GmailMessagesBatchModify

pub fn new( auth: &HttpAuthBearer, user_id: &str, ids: &[String], add_label_ids: &[String], remove_label_ids: &[String], ) -> Result<Self, GmailSendError>

Builds the users.messages.batchModify request adding and removing the given label ids on the given message ids.