pub enum GmailInternalDateSource {
ReceivedTime,
DateHeader,
}Expand description
Source of the internal date when importing or inserting a message
(internalDateSource query parameter).
Variants
ReceivedTime
The internal date is the time the message was received.
DateHeader
The internal date comes from the Date header of the message.