pub enum GmailMessageListVisibility {
Show,
Hide,
}Expand description
Whether messages carrying a label show up in the message list.
Variants
Show
Messages with the label show in the message list.
Hide
Messages with the label are hidden from the message list.