pub struct GmailMessagePartBody {
pub attachment_id: Option<String>,
pub size: u32,
pub data: Option<String>,
}Expand description
The body of a single MIME part of a Gmail message.
Fields
attachment_id: Option<String>The id of an external attachment, retrievable via a separate
users.messages.attachments.get request.
size: u32The number of bytes of the message part data.
data: Option<String>The body data as a base64url-encoded string; absent when the data lives in an external attachment.