pub enum GmailDisposition {
DispositionUnspecified,
LeaveInInbox,
Archive,
Trash,
MarkRead,
}Expand description
Action applied to a message after it has been forwarded or fetched.
Variants
DispositionUnspecified
No disposition specified.
LeaveInInbox
Leave the message untouched in the inbox.
Archive
Archive the message.
Trash
Move the message to the trash.
MarkRead
Leave the message in the inbox but mark it as read.