pub struct GmailAutoForwarding {
pub enabled: bool,
pub email_address: Option<String>,
pub disposition: Option<GmailDisposition>,
}Expand description
Auto-forwarding settings of a Gmail account.
Fields
enabled: boolWhether all incoming mail is automatically forwarded to another address.
email_address: Option<String>Email address to which all incoming messages are forwarded.
disposition: Option<GmailDisposition>Action applied to messages after they have been forwarded.