pub struct GmailThread {
pub id: String,
pub snippet: Option<String>,
pub history_id: Option<String>,
pub messages: Vec<GmailMessage>,
}Expand description
A Gmail thread resource.
A thread groups related messages into a single conversation.
Fields
id: StringImmutable identifier of the thread.
snippet: Option<String>Short part of the message text.
history_id: Option<String>Id of the last history record that modified the thread.
messages: Vec<GmailMessage>Messages belonging to the thread.