pub struct GmailMessagesBatchModify { /* private fields */ }Expand description
Gmail REST batch message label modification, yielding no response body.
Implementations
Sourceimpl GmailMessagesBatchModify
impl GmailMessagesBatchModify
Sourcepub fn new(
auth: &HttpAuthBearer,
user_id: &str,
ids: &[String],
add_label_ids: &[String],
remove_label_ids: &[String],
) -> Result<Self, GmailSendError>
pub fn new( auth: &HttpAuthBearer, user_id: &str, ids: &[String], add_label_ids: &[String], remove_label_ids: &[String], ) -> Result<Self, GmailSendError>
Builds the users.messages.batchModify request adding and
removing the given label ids on the given message ids.